==> tuia-advert-center-api-2.0.0-sources.jar: cn/com/duiba/tuia/core/api/dto/req/MediaTagReq.java <==
package cn.com.duiba.tuia.core.api.dto.req;

import java.io.Serializable;
import java.util.List;

/**
 * Created by huangch on 2018/8/2 15:29
 * description:
 *
 * @since JDK 1.6
 */
public class MediaTagReq  implements Serializable {

    private static final long serialVersionUID = -5087020552127549205L;

    //需要查询或者返回的广告类型。1-互动广告、2-展示广告
    private Integer advertType;

    //需要过滤的原始广告ID集合(新广告)
    private List<Long> advertIds;

    //需要查询的行业标签列表（二级标签）
    private List<String> industryTags;

    //媒体屏蔽的属性标签列表（二级标签）
    private List<String> shieldAdvertTags;

    //媒体屏蔽的落地页标签列表（二级标签）
    private List<String> shieldPromoteTags;

    //媒体屏蔽的行业标签列表（二级标签）
    private List<String> shieldIndustryTags;

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public List<String> getIndustryTags() {
        return industryTags;
    }

    public void setIndustryTags(List<String> industryTags) {
        this.industryTags = industryTags;
    }

    public List<String> getShieldAdvertTags() {
        return shieldAdvertTags;
    }

    public void setShieldAdvertTags(List<String> shieldAdvertTags) {
        this.shieldAdvertTags = shieldAdvertTags;
    }

    public List<String> getShieldPromoteTags() {
        return shieldPromoteTags;
    }

    public void setShieldPromoteTags(List<String> shieldPromoteTags) {
        this.shieldPromoteTags = shieldPromoteTags;
    }

    public List<String> getShieldIndustryTags() {
        return shieldIndustryTags;
    }

    public void setShieldIndustryTags(List<String> shieldIndustryTags) {
        this.shieldIndustryTags = shieldIndustryTags;
    }
}

==> tuia-advert-center-api-2.0.6-sources.jar: cn/com/duiba/tuia/core/api/dto/req/MediaTagReq.java <==
package cn.com.duiba.tuia.core.api.dto.req;

import java.io.Serializable;
import java.util.List;

/**
 * Created by huangch on 2018/8/2 15:29
 * description:
 *
 * @since JDK 1.6
 */
public class MediaTagReq  implements Serializable {

    private static final long serialVersionUID = -5087020552127549205L;

    //操作媒体平台的请求的IP
    private String requestIp;

    //需要查询或者返回的广告类型。1-互动广告、2-展示广告
    private Integer advertType;

    //需要过滤的原始广告ID集合(新广告)
    private List<Long> advertIds;

    //需要查询的行业标签列表（二级标签）
    private List<String> industryTags;

    //媒体屏蔽的属性标签列表（二级标签）
    private List<String> shieldAdvertTags;

    //媒体屏蔽的落地页标签列表（二级标签）
    private List<String> shieldPromoteTags;

    //媒体屏蔽的行业标签列表（二级标签）
    private List<String> shieldIndustryTags;

    public String getRequestIp() {
        return requestIp;
    }

    public void setRequestIp(String requestIp) {
        this.requestIp = requestIp;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public List<String> getIndustryTags() {
        return industryTags;
    }

    public void setIndustryTags(List<String> industryTags) {
        this.industryTags = industryTags;
    }

    public List<String> getShieldAdvertTags() {
        return shieldAdvertTags;
    }

    public void setShieldAdvertTags(List<String> shieldAdvertTags) {
        this.shieldAdvertTags = shieldAdvertTags;
    }

    public List<String> getShieldPromoteTags() {
        return shieldPromoteTags;
    }

    public void setShieldPromoteTags(List<String> shieldPromoteTags) {
        this.shieldPromoteTags = shieldPromoteTags;
    }

    public List<String> getShieldIndustryTags() {
        return shieldIndustryTags;
    }

    public void setShieldIndustryTags(List<String> shieldIndustryTags) {
        this.shieldIndustryTags = shieldIndustryTags;
    }
}
